==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/azuredatatransfer/kotlin/outputs/PendingFlowResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azuredatatransfer.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Pending flow object
 * @property connection The connection associated with this flow
 * @property connectionId Connection ID of the pending flow.
 * @property dataType Transfer Storage Blobs or Tables
 * @property flowId Dataflow GUID associated with this flow
 * @property flowType The flow type for this flow
 * @property id Fully qualified resource ID for the resource. E.g. "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}"
 * @property keyVaultUri AME, PME, or TORUS only! AKV Chain Containing SAS Token
 * @property linkStatus Link status of the current flow
 * @property linkedFlowId Resource ID of the linked flow
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property policies The policies for this flow
 * @property provisioningState Provisioning state of the flow
 * @property schema The selected schema for this flow
 * @property serviceBusQueueId Service Bus Queue ID
 * @property status Status of the current flow
 * @property storageAccountId Storage Account ID
 * @property storageAccountName Storage Account
 * @property storageContainerName Storage Container Name
 * @property subscriptionId Subscription ID of the pending flow.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class PendingFlowResponse(
    public val connection: SelectedResourceResponse? = null,
    public val connectionId: String,
    public val dataType: String? = null,
    public val flowId: String,
    public val flowType: String? = null,
    public val id: String,
    public val keyVaultUri: String? = null,
    public val linkStatus: String,
    public val linkedFlowId: String,
    public val location: String,
    public val name: String,
    public val policies: List<String>? = null,
    public val provisioningState: String,
    public val schema: SchemaResponse? = null,
    public val serviceBusQueueId: String? = null,
    public val status: String? = null,
    public val storageAccountId: String? = null,
    public val storageAccountName: String? = null,
    public val storageContainerName: String? = null,
    public val subscriptionId: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.azuredatatransfer.outputs.PendingFlowResponse):
            PendingFlowResponse = PendingFlowResponse(
            connection = javaType.connection().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azuredatatransfer.kotlin.outputs.SelectedResourceResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            connectionId = javaType.connectionId(),
            dataType = javaType.dataType().map({ args0 -> args0 }).orElse(null),
            flowId = javaType.flowId(),
            flowType = javaType.flowType().map({ args0 -> args0 }).orElse(null),
            id = javaType.id(),
            keyVaultUri = javaType.keyVaultUri().map({ args0 -> args0 }).orElse(null),
            linkStatus = javaType.linkStatus(),
            linkedFlowId = javaType.linkedFlowId(),
            location = javaType.location(),
            name = javaType.name(),
            policies = javaType.policies().map({ args0 -> args0 }),
            provisioningState = javaType.provisioningState(),
            schema = javaType.schema().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azuredatatransfer.kotlin.outputs.SchemaResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            serviceBusQueueId = javaType.serviceBusQueueId().map({ args0 -> args0 }).orElse(null),
            status = javaType.status().map({ args0 -> args0 }).orElse(null),
            storageAccountId = javaType.storageAccountId().map({ args0 -> args0 }).orElse(null),
            storageAccountName = javaType.storageAccountName().map({ args0 -> args0 }).orElse(null),
            storageContainerName = javaType.storageContainerName().map({ args0 -> args0 }).orElse(null),
            subscriptionId = javaType.subscriptionId(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.azuredatatransfer.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/azuredatatransfer/kotlin/outputs/PendingFlowResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azuredatatransfer.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Pending flow object
 * @property connection The connection associated with this flow
 * @property connectionId Connection ID of the pending flow.
 * @property dataType Transfer Storage Blobs or Tables
 * @property flowId Dataflow GUID associated with this flow
 * @property flowType The flow type for this flow
 * @property id Fully qualified resource ID for the resource. E.g. "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}"
 * @property keyVaultUri AME, PME, or TORUS only! AKV Chain Containing SAS Token
 * @property linkStatus Link status of the current flow
 * @property linkedFlowId Resource ID of the linked flow
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property policies The policies for this flow
 * @property provisioningState Provisioning state of the flow
 * @property schema The selected schema for this flow
 * @property serviceBusQueueId Service Bus Queue ID
 * @property status Status of the current flow
 * @property storageAccountId Storage Account ID
 * @property storageAccountName Storage Account
 * @property storageContainerName Storage Container Name
 * @property subscriptionId Subscription ID of the pending flow.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class PendingFlowResponse(
    public val connection: SelectedResourceResponse? = null,
    public val connectionId: String,
    public val dataType: String? = null,
    public val flowId: String,
    public val flowType: String? = null,
    public val id: String,
    public val keyVaultUri: String? = null,
    public val linkStatus: String,
    public val linkedFlowId: String,
    public val location: String,
    public val name: String,
    public val policies: List<String>? = null,
    public val provisioningState: String,
    public val schema: SchemaResponse? = null,
    public val serviceBusQueueId: String? = null,
    public val status: String? = null,
    public val storageAccountId: String? = null,
    public val storageAccountName: String? = null,
    public val storageContainerName: String? = null,
    public val subscriptionId: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.azuredatatransfer.outputs.PendingFlowResponse): PendingFlowResponse = PendingFlowResponse(
            connection = javaType.connection().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azuredatatransfer.kotlin.outputs.SelectedResourceResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            connectionId = javaType.connectionId(),
            dataType = javaType.dataType().map({ args0 -> args0 }).orElse(null),
            flowId = javaType.flowId(),
            flowType = javaType.flowType().map({ args0 -> args0 }).orElse(null),
            id = javaType.id(),
            keyVaultUri = javaType.keyVaultUri().map({ args0 -> args0 }).orElse(null),
            linkStatus = javaType.linkStatus(),
            linkedFlowId = javaType.linkedFlowId(),
            location = javaType.location(),
            name = javaType.name(),
            policies = javaType.policies().map({ args0 -> args0 }),
            provisioningState = javaType.provisioningState(),
            schema = javaType.schema().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azuredatatransfer.kotlin.outputs.SchemaResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            serviceBusQueueId = javaType.serviceBusQueueId().map({ args0 -> args0 }).orElse(null),
            status = javaType.status().map({ args0 -> args0 }).orElse(null),
            storageAccountId = javaType.storageAccountId().map({ args0 -> args0 }).orElse(null),
            storageAccountName = javaType.storageAccountName().map({ args0 -> args0 }).orElse(null),
            storageContainerName = javaType.storageContainerName().map({ args0 -> args0 }).orElse(null),
            subscriptionId = javaType.subscriptionId(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.azuredatatransfer.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}
